@@ -2417,6 +2417,33 @@ class Extrinsic(GenericExtrinsic):
     pass
 
 
+class GenericExtrinsicV4(Struct):
+
+    def __init__(self, *args, **kwargs):
+
+        if 'metadata' in kwargs and 'extrinsic' in kwargs['metadata'][1][1]:
+
+            # Build type mapping according to signed extensions in metadata
+            self.type_mapping = [['address', 'Address'], ['signature', 'ExtrinsicSignature']]
+
+            # Process signed extensions in metadata
+            if 'signed_extensions' in kwargs['metadata'][1][1]['extrinsic']:
+                signed_extensions = kwargs['metadata'][1][1]['extrinsic']['signed_extensions'].value
+
+                if 'CheckMortality' in signed_extensions:
+                    self.type_mapping.append(['era', 'Era'])
+
+                if 'CheckNonce' in signed_extensions:
+                    self.type_mapping.append(['nonce', 'Compact<Index>'])
+
+                if 'ChargeTransactionPayment' in signed_extensions:
+                    self.type_mapping.append(['tip', 'Compact<Balance>'])
+
+            self.type_mapping.append(['call', 'Call'])
+
+        super().__init__(*args, **kwargs)
+
+
 class GenericEvent(Enum):
 
     def __init__(self, *args, **kwargs):
@@ -2643,20 +2670,3 @@ class GenericPreRuntime(Struct):
             self.slot_number = aura_predigest.value['slot_number']
 
         return value
-
-
-class LogDigest(Enum):
-
-    value_list = ['Other', 'AuthoritiesChange', 'ChangesTrieRoot', 'SealV0', 'Consensus', 'Seal', 'PreRuntime']
-
-    def __init__(self, data, **kwargs):
-        self.log_type = None
-        self.index_value = None
-        super().__init__(data, **kwargs)
-
-    def process(self):
-        self.index = int(self.get_next_bytes(1).hex())
-        self.index_value = self.value_list[self.index]
-        self.log_type = self.process_type(self.value_list[self.index])
-
-        return {'type': self.value_list[self.index], 'value': self.log_type.value}
